Bacteria
=======================================
Bacteira is a python library to analyze supersegger data.

Installation
=======================================

The latest stable release is available on PyPi, and you can install it by saying

``pip install bacteria``

To build Bacteria from source, say ``python setup.py build``.
Then, to install Bacteria, say ``python setup.py install``.
If all went well, you should be able to execute the demo scripts (read docs)
(OS X users should follow the installation guide given below).

Alternatively, you can download or clone the repository and use `pip` to handle dependencies:


``unzip bacteria.zip``

``pip install -e bacteria``

or

``git clone https://github.com/tuliofalmeida/bacteria``

``pip install -e bacteria``

By calling ``pip list`` you should see ``bacteria`` now as an installed package:
``bacteria (1.x.x, /path/to/bacteria)``

Documentation
=======================================
`Documentation site`_

.. _Documentation site: https://bacteria.rtfd.io

Pipeline
=========
I also developed a `Pipeline`_ to analyze SuperSegger-Omnipose data in a more fluid way using python and being able to run multiple experiments at once 

.. _Pipeline: https://github.com/tuliofalmeida/bacteria/tree/main/pipeline
